#!/usr/bin/python
# Copyright 2016 Mellanox Technologies, Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import re
import yaml
import logging
import sys
from yaml.parser import ParserError
from params import OvercloudParams
from params import EnvParams


def read_yaml_file(file_path):
    try:
        f = open(file_path, "r")
        ifc_dict = yaml.safe_load(f)
        f.close()
        return ifc_dict
    except IOError as er:
        logging.error("file not found: " + file_path)
        sys.exit(1)
    except ParserError as er:
        logging.error("ParserError in yaml file:" + file_path)
        logging.error(er)
        sys.exit(1)


def generate_rules_file(new_dict):
    mac_regx = re.compile(r'^([0-9A-F]{2}[:-]){5}([0-9A-F]{2})$',
                          re.IGNORECASE)
    out_file = ""
    for hostname in new_dict:
        out_file += '# rules for host: {0}'.format(hostname)
        out_file += '\n'

        for ifc_name in new_dict[hostname]['interfaces']:
            interface_dict = new_dict[hostname]['interfaces'][ifc_name]
            if 'new_name' in interface_dict:
                new_name = interface_dict['new_name']
                new_name = new_name.strip()
                mac = re.search(mac_regx, interface_dict['mac'].strip())
                if mac:
                    if new_name:
                        out_file += OvercloudParams.UDEV_RULE_LINE % (
                            interface_dict['mac'], "0x0", new_name)
                        out_file += '\n'
                    else:
                        out_file += OvercloudParams.UDEV_RULE_LINE % (
                            interface_dict['mac'], "0x0", ifc_name)
                        out_file += '\n'

    return out_file


def write_rules_file(content):
    try:
        out_file = '{0}/{1}'.format(EnvParams.TMP_FILES_DIR_PATH,
                                    OvercloudParams.UDEV_RULES_FILE_NAME)
        f = open(out_file, "w")
        f.write(content)
        f.close()
    except Exception as ex:
        logging.error(ex)
        sys.exit(1)


def main(yaml_file_path):
    # init logger
    logging.basicConfig(format='%(asctime)s %(filename)s %(message)s',
                        level=logging.DEBUG,
                        filename=EnvParams.LOG_FILE_PATH)

    ifc_dict = read_yaml_file(yaml_file_path)
    out_file = generate_rules_file(ifc_dict)
    if not out_file:
        logging.info("no rules generated")
        sys.exit(0)

    # write rules file
    write_rules_file(out_file)
    logging.debug("interface file generated successfully")


# arg is path to 'interfaces_drivers.yaml' generated from 'check_interfaces.py'
if __name__ == "__main__":
    main(sys.argv[1])
