#!/bin/bash -x
# Copyright 2017 Mellanox Technologies, Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.


. /opt/mlnx_scripts/common

function add_ceph_config () {
  KEY=$1
  VALUE=$2
  LINE=$KEY\=$VALUE
  grep $KEY /etc/ceph/ceph.conf > /dev/null
  if [ $? -eq 0 ]; then
    sed -i "/$KEY.*/ c\\$LINE" /etc/ceph/ceph.conf
  else
    sed -i "s/\[global\]/[global]\n$LINE/" /etc/ceph/ceph.conf
  fi
}


function set_unlimited_memory () {
  tee -a /etc/security/limits.conf << EOT
* soft memlock unlimited
* hard memlock unlimited
root soft memlock unlimited
root hard memlock unlimited
EOT
}


function stop_ceph () {
  systemctl stop ceph.target
}

function start_ceph () {
  systemctl start ceph.target
}

function install_ceph () {
  yum -y install ceph
}



##      ##
#  MAIN  #
##      ##

storage_backend=$(get_mlnx_extra_param storage_backend)
storage_rdma_enable=$(get_mlnx_extra_param storage_rdma_enable)
if [ $storage_backend == ceph ] && [ $storage_rdma_enable == True ]
    # INSTALL CEPH PACKAGES
    then
        ifname=$(get_mlnx_extra_param storage_ifc_name)

        if [ $? -ne 0 ] || [[ -z "${ifname// }" ]]; then
            logger_print error "Error: storage interface not found"
            exit 1
        fi

        # get physical name from interface name
        device_name=`ibdev2netdev | grep $ifname | awk '{print $1}'`

        # stop Ceph services before installing Ceph RDMA
        stop_ceph

        # install Ceph RDMA packages
        install_ceph

        # add RDMA attributes to /etc/ceph/ceph.conf
        add_ceph_config ms_cluster_type async+rdma
        add_ceph_config ms_async_rdma_send_buffers 512
        add_ceph_config ms_async_rdma_receive_buffers 512
        add_ceph_config ms_async_rdma_device_name $device_name

        # set unlimited physical memory for RDMA
        set_unlimited_memory

        # start Ceph RDMA service
        start_ceph
fi
