#!/usr/bin/env python
# Copyright 2016 Mellanox Technologies, Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os


DEPLOY_SRC_DIR_PATH = os.path.dirname(os.path.abspath(__file__))
PARENT_PKG_PATH = os.path.abspath(os.path.join(DEPLOY_SRC_DIR_PATH, os.pardir))


class EnvParams:

    METADATA_FILE = 'metadata.yaml'
    ENV_CONF_DIR = 'environment_conf'
    DEPLOY_SRC_DIR = 'deployment_sources'
    NETWORK_CONF_DIR = 'network'
    OVC_SCRIPTS_DIR = 'overcloud_scripts'
    SCRIPTS_DIR = 'scripts'
    TMP_FILES_DIR = 'tmp_files'
    FIRSTBOOT_SCRIPT = 'firstboot'

    METADATA_FILE_PATH = os.path.join(PARENT_PKG_PATH, METADATA_FILE)
    ENV_CONF_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, ENV_CONF_DIR)
    NETWORK_CONF_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, NETWORK_CONF_DIR)
    OVC_SCRIPTS_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, OVC_SCRIPTS_DIR)
    SCRIPTS_DIR_PATH = os.path.join(OVC_SCRIPTS_DIR_PATH, SCRIPTS_DIR)
    TMP_FILES_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, TMP_FILES_DIR)
    FIRSTBOOT_SCRIPT_PATH = os.path.join(TMP_FILES_DIR_PATH, FIRSTBOOT_SCRIPT)

    CONF_FILE_NAME = 'config.yaml'
    NETWORK_CONF_FILE_NAME = 'network_env.yaml'
    NETWORK_CONF_TEMPLATE_FILE_NAME = 'network_env-template.yaml'
    COMMON_SCRIPT = 'common'
    RESTART_SERVICE_SCRIPT = 'restart_service.sh'
    LOG_FILE = 'mellanox-rhel-osp.log'
    ENV_YAML_FILE = 'env.yaml'
    ENV_TEMPLATE_YAML_FILE = 'env-template.yaml'
    NEUTRON_SRIOV_YAML_FILE = 'neutron-sriov.yaml'
    NEUTRON_SRIOV_TEMPLATE_YAML_FILE = 'neutron-sriov-template.yaml'
    NEUTRON_OVS_DPDK_TEMPLATE_YAML_FILE = 'neutron-ovs-dpdk-template.yaml'
    NEUTRON_OVS_DPDK_YAML_FILE = 'neutron-ovs-dpdk.yaml'
    INTERFACES_DRIVERS_YAML_FILE = 'interfaces_drivers.yaml'

    ENV_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH, ENV_YAML_FILE)
    ENV_TEMPLATE_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH,
                                               ENV_TEMPLATE_YAML_FILE)
    NEUTRON_SRIOV_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH,
                                                NEUTRON_SRIOV_YAML_FILE)
    NEUTRON_SRIOV_TEMPLATE_YAML_FILE_PATH = os.path.join(
        ENV_CONF_DIR_PATH,
        NEUTRON_SRIOV_TEMPLATE_YAML_FILE)
    NEUTRON_OVS_DPDK_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH,
                                                   NEUTRON_OVS_DPDK_YAML_FILE)
    NEUTRON_OVS_DPDK_TEMPLATE_YAML_FILE_PATH = os.path.join(
        ENV_CONF_DIR_PATH,
        NEUTRON_OVS_DPDK_TEMPLATE_YAML_FILE)
    INTERFACES_DRIVERS_YAML_FILE_PATH = os.path.join(
        ENV_CONF_DIR_PATH,
        INTERFACES_DRIVERS_YAML_FILE)
    CONF_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH, CONF_FILE_NAME)
    NETWORK_CONF_FILE_PATH = os.path.join(NETWORK_CONF_DIR_PATH,
                                          NETWORK_CONF_FILE_NAME)
    NETWORK_CONF_TEMPLATE_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH,
                     NETWORK_CONF_TEMPLATE_FILE_NAME)
    COMMON_SCRIPT_PATH = os.path.join(SCRIPTS_DIR_PATH, COMMON_SCRIPT)
    RESTART_SERVICE_PATH = os.path.join(SCRIPTS_DIR_PATH,
                                        RESTART_SERVICE_SCRIPT)
    LOG_FILE_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, LOG_FILE)

    OVC_FULL_IMAGE_NAME = 'overcloud-full.qcow2'
    MNT_OFED_DIR_PATH = os.path.join('/mnt', 'ofed')
    OFED_VERSION_FILE = '.mlnx'
    OFED_DISTRO_FILE = 'distro'
    OFED_ARCH_FILE = '.arch'
    OFED_VERSION_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_VERSION_FILE)
    OFED_DISTRO_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_DISTRO_FILE)
    OFED_ARCH_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_ARCH_FILE)

    STACKRC_FILE_NAME = 'stackrc'
    STACKRC_FILE_PATH = os.path.join(
        os.path.expanduser('~'), STACKRC_FILE_NAME)

    LIBVIRT_SERVICE = 'libvirtd'
    CEPH_RDMA_REPO_FILE_NAME = 'mlnx_ceph.repo'
    CEPH_RDMA_REPO_FILE = os.path.join(
        DEPLOY_SRC_DIR_PATH, CEPH_RDMA_REPO_FILE_NAME)
    TRIPLEO_TEMPLATES_PATH = '/usr/share/openstack-tripleo-heat-templates'
    TRIPLEO_SERVICES_PATH = os.path.join(TRIPLEO_TEMPLATES_PATH,
                                         'puppet/services/')
    CEPH_MON_YAML_FILE = 'ceph-mon.yaml'
    CEPH_OSD_YAML_FILE = 'ceph-osd.yaml'
    CEPH_CLIENT_YAML_FILE = 'ceph-client.yaml'
    CEPH_MON_YAML_FILE_PATH = os.path.join(TRIPLEO_SERVICES_PATH,
                                           CEPH_MON_YAML_FILE)
    CEPH_OSD_YAML_FILE_PATH = os.path.join(TRIPLEO_SERVICES_PATH,
                                           CEPH_OSD_YAML_FILE)
    CEPH_CLIENT_YAML_FILE_PATH = os.path.join(TRIPLEO_SERVICES_PATH,
                                              CEPH_CLIENT_YAML_FILE)
    CEPH_STORAGE_ROLE = 'CephStorage'
    BLOCK_STORAGE_ROLE = 'BlockStorage'
    CONTROLLER_ROLE = 'Controller'
    COMPUTE_ROLE = ' Compute'
    TRIPLEO_NETWORK_PATH = os.path.join(TRIPLEO_TEMPLATES_PATH, "network")
    TRIPLEO_PORTS_PATH = os.path.join(TRIPLEO_NETWORK_PATH, "ports")

    NOOP_PORT = os.path.join(TRIPLEO_PORTS_PATH, "noop.yaml")
    STORAGE_PORT = os.path.join(TRIPLEO_PORTS_PATH, "storage.yaml")
    STORAGE_MGMT_PORT = os.path.join(TRIPLEO_PORTS_PATH, "storage_mgmt.yaml")
    TRIPLEO_PORT_STORAGE = "OS::TripleO::{0}::Ports::StoragePort"
    TRIPLEO_PORT_STORAGE_MGMT = "OS::TripleO::{0}::Ports::StorageMgmtPort"
    TRIPLEO_NETWORK_STORAGE_MGMT = "OS::TripleO::Network::StorageMgmt"
    STORAGE_MGMT_NETWORK = os.path.join(TRIPLEO_NETWORK_PATH,
                                        "storage_mgmt.yaml")
    TRIPLEO_PORT_VIP_STORAGE_MGMT = \
        "OS::TripleO::Network::Ports::StorageMgmtVipPort"

    STORAGE_TEMPLATE_FILE_NAME = 'storage-template.yaml'
    CONTROLLER_TEMPLATE_FILE_NAME = 'controller-template.yaml'
    COMPUTE_TEMPLATE_FILE_NAME = 'compute-template.yaml'

    STORAGE_TEMPLATE_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, STORAGE_TEMPLATE_FILE_NAME)
    CONTROLLER_TEMPLATE_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, CONTROLLER_TEMPLATE_FILE_NAME)
    COMPUTE_TEMPLATE_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, COMPUTE_TEMPLATE_FILE_NAME)

    STORAGE_NETWORK_FILE_NAME = 'storage.yaml'
    CONTROLLER_NETWORK_FILE_NAME = 'controller.yaml'
    COMPUTE_NETWORK_FILE_NAME = 'compute.yaml'

    STORAGE_NETWORK_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, STORAGE_NETWORK_FILE_NAME)
    CONTROLLER_NETWORK_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, CONTROLLER_NETWORK_FILE_NAME)
    COMPUTE_NETWORK_FILE_PATH = \
        os.path.join(NETWORK_CONF_DIR_PATH, COMPUTE_NETWORK_FILE_NAME)


class OvercloudParams:

    OVC_MLNX_PATH = '/opt'
    OFED_DIR = 'ofed'
    OVC_MLNX_SCRIPTS_DIR = 'mlnx_scripts'
    OVC_MLNX_PKGS_DIR = 'mlnx_packages'
    OVC_TARGET_OS_DIR_PATH = '/'
    OVC_TARGET_OS = 'target_os'
    UDEV_RULES_FILE_PATH = '/etc/udev/rules.d/'
    UDEV_RULES_FILE_NAME = '70-persistent-net.rules'
    UDEV_RULE_LINE = 'SUBSYSTEM=="net", ' \
                     'ACTION=="add", ' \
                     'DRIVERS=="?*", ' \
                     'ATTR{address}=="%s", ' \
                     'ATTR{dev_id}=="%s", ' \
                     'ATTR{type}=="1", ' \
                     'KERNEL=="eth*", ' \
                     'NAME="%s"'

    OVC_OFED_DIR_PATH = os.path.join(OVC_MLNX_PATH, OFED_DIR)
    OVC_MLNX_SCRIPTS_DIR_PATH = os.path.join(
        OVC_MLNX_PATH, OVC_MLNX_SCRIPTS_DIR)
    OVC_MLNX_PKGS_DIR_PATH = os.path.join(
        OVC_MLNX_PATH, OVC_MLNX_PKGS_DIR)
    RESTART_SERVICE_PATH = os.path.join(OVC_MLNX_SCRIPTS_DIR_PATH,
                                        EnvParams.RESTART_SERVICE_SCRIPT)
    GRUB_FILE_PATH = os.path.join('/etc', 'default')
    OFED_PREFIX = 'MLNX_OFED_LINUX'
    LLDPD_CONF_FILE_PATH = os.path.join('/etc', 'lldpd.conf')
    OVS_DPDK_PACKAGES_DIR = 'ovs-rpms'
    TMP_OVS_DPDK_PACKAGES_SOURCE_DIR = os.path.join(
        EnvParams.TMP_FILES_DIR_PATH,
        OVS_DPDK_PACKAGES_DIR)
    MLNX_OVS_DPDK_RPMS_SOURCE = 'http://bgate.mellanox.com/openstack/' \
                                'repository/redhat/7-openstack-ocata/'
    MLNX_OVS_DPDK_RPMS_VERSION = '2.6.1-10.git20161206.el7.x86_64'
    MLNX_OVS_DPDK_RPMS_LIST = ['openvswitch',
                               'openvswitch-ovn-central',
                               'openvswitch-ovn-common',
                               'openvswitch-ovn-host']
    MLNX_OVS_DPDK_RPMS_URLS_LIST = ['{0}%s-{1}.rpm'.format(
        MLNX_OVS_DPDK_RPMS_SOURCE,
        MLNX_OVS_DPDK_RPMS_VERSION)
        % p for p in MLNX_OVS_DPDK_RPMS_LIST]
    OVS_DPDK_PACKAGES_PATH = os.path.join(OVC_MLNX_PATH,
                                          OVS_DPDK_PACKAGES_DIR)
    YUM_REPO_FOLDER = '/etc/yum.repos.d/'
    CEPH_PACKAGES_DIR = 'mlnx-ceph'
    TMP_CEPH_PACKAGES_SOURCE_DIR = os.path.join(
        EnvParams.TMP_FILES_DIR_PATH,
        CEPH_PACKAGES_DIR)


class PackageParams:

    LLDPD = 'lldpd'
    PYZMQ = 'python-zmq'
    LIBZMQ = 'libzmq3'
    MLNX_REPO_URL = 'http://www.mellanox.com/repository/solutions/' \
                    'openstack/mitaka/redhat/7/'
    MLNX_REPO = 'mellanox.com_repository_solutions_openstack_mitaka_redhat_7_'
    PYTHON_NET_MLNX = 'python-networking-mlnx'
    PYTHON_NET_MLNX_URL = 'https://buildlogs.centos.org/centos/7/cloud/' \
                          'x86_64/rdo-trunk-mitaka-tested/'
    PYTHON_NETWORKING_MLNX_REPO = 'buildlogs.centos.org_centos_7_cloud_' \
                                  'x86_64_rdo-trunk-mitaka-tested_'
