#!/usr/bin/env python
# Copyright 2016 Mellanox Technologies, Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import subprocess
import logging
import yaml
import argparse
import sys
import os
from ConfigParser import SafeConfigParser
from params import EnvParams

parser = argparse.ArgumentParser(
    prog=os.path.basename(sys.argv[0]),
    formatter_class=argparse.RawDescriptionHelpFormatter)


def run_command(cmd):

    try:
        p_output = subprocess.check_output(
            cmd, shell=True, stderr=subprocess.STDOUT)
        logging.info(p_output)
        return p_output

    except subprocess.CalledProcessError as e:
        error_msg = 'Failed running command : {0}'.format(cmd)
        print error_msg, e.output
        logging.error(e.output)
        sys.exit(1)


def load_file(file):
    data = ''
    with open(file, 'r') as stream:
        try:
            data = yaml.load(stream)
        except yaml.YAMLError as exc:
            print(exc)
    stream.close()
    return data


def check_bool(value):

    if type(value) != bool:
        try:
            cp = SafeConfigParser()
            cp.add_section('booleans')
            cp.set('booleans', 'key', value)
            value = cp.getboolean('booleans', 'key')
        except (ValueError, AttributeError, TypeError):
            if value is None:
                parser.error('Please fill all required boolean params '
                             'in config.yaml.')
            else:
                parser.error("Invalid boolean value in config.yaml: {0}"
                             .format(value))

    return value


def install_libguestsfs():
    """
    Install libguestfs packages.
    """
    run_command('source {0}'.format(os.path.join('~', 'stackrc')))
    run_command('sudo yum install -y libguestfs-xfs')
    run_command('sudo yum install -y libguestfs-tools')
    run_command('export LIBGUESTFS_BACKEND=direct')


def check_libvirtd():
    """
    Check libvirtd status if active.
    """
    status = run_command("echo $(systemctl is-active {0})"
                         .format(EnvParams.LIBVIRT_SERVICE))
    if status.strip() != 'active':
        error_msg = 'LibvirtD service is not active. ' \
                    'Please activate it and try again.\n'
        logging.error(error_msg)
        sys.stderr.write(error_msg)
        sys.exit(1)
